#!/usr/bin/env python
# coding: utf-8
# Copyright (c) 2018
#

__version__ = '0.0.17'

from .oss import OSSStorage
from .s3 import S3Storage
from .jms import JMSReplayStorage, JMSCommandStorage
from .es import ESStorage
from .multi import MultiObjectStorage


def get_object_storage(config):
    if config.get("TYPE") == "s3":
        return S3Storage(config)
    elif config.get("TYPE") == "oss":
        return OSSStorage(config)
    elif config.get("TYPE") == "server":
        return JMSReplayStorage(config)
    else:
        raise Exception("Not found proper storage")


def get_log_storage(config):
    if config.get("TYPE") in ("es", "elasticsearch"):
        return ESStorage(config)
    elif config.get("TYPE") == "server":
        return JMSCommandStorage(config)
    else:
        raise Exception("Not found proper storage")


def get_multi_object_storage(configs):
    return MultiObjectStorage(configs)



#!/usr/bin/env python
# coding: utf-8
# Copyright (c) 2018
import re

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('jms_storage/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

with open('README.md', 'rb') as f:
    readme = f.read().decode('utf-8')

with open('requirements.txt', 'r') as f:
    requirements = [x.strip() for x in f.readlines()]

setup(
    name='jms-storage',
    version=version,
    keywords=['jumpserver', 'storage', 'oss', 's3', 'elasticsearch'],
    description='Jumpserver storage python sdk tools',
    long_description=readme,
    license='MIT Licence',
    url='http://www.jumpserver.org/',
    author='Jumpserver team',
    author_email='support@fit2cloud.com',
    packages=['jms_storage'],
    data_files=[('requirements', ['requirements.txt'])],
    include_package_data=True,
    install_requires=requirements,
    platforms='any',
)



# -*- coding: utf-8 -*-
#

from .base import ObjectStorage, LogStorage


class MultiObjectStorage(ObjectStorage):

    def __init__(self, configs):
        self.configs = configs
        self.storage_list = []
        self.init_storage_list()

    def init_storage_list(self):
        from . import get_object_storage
        if isinstance(self.configs, dict):
            configs = self.configs.values()
        else:
            configs = self.configs

        for config in configs:
            self.storage_list.append(get_object_storage(config))

    def upload(self, src, target):
        success = []
        msg = []

        for storage in self.storage_list:
            ok, err = storage.upload(src, target)
            success.append(ok)
            msg.append(err)

        return success, msg

    def download(self, src, target):
        success = False
        msg = None

        for storage in self.storage_list:
            if storage.exists(src):
                ok, msg = storage.download(src, target)
                if ok:
                    success = True
                    break
        return success, msg

    def delete(self, path):
        success = True
        msg = None

        for storage in self.storage_list:
            if storage.exists(path):
                ok, msg = storage.delete(path)
                if not ok:
                    success = False
        return success, msg

    def exists(self, path):
        for storage in self.storage_list:
            if storage.exists(path):
                return True
        return False

